function advectionDiffusionMQ()

    dt = 0.005;  finalTime = 0.5;
     a = 1;    nu = 0.002;           % advection and diffusion coefficients
  shape = 6;  N = 51;                % total collocation points
      x = linspace(0,1,N)';  
      
      o = ones(1,length(x));
     rx = x*o - (x*o)';  % signed distance matrix 
      r = abs(rx);       %  distance matrix

          H = zeros(N,N);   % evaluation matrix 
     H(1,:) = mq(r(1,:),shape);        % Dirichlet BC at x=0
 H(2:N-1,:) = nu.*mqDerivatives(r(2:N-1,:),rx(2:N-1,:),shape,2) - ...                   
               a.*mqDerivatives(r(2:N-1,:),rx(2:N-1,:),shape,1);                                 
     H(N,:) = mq(r(N,:),shape);         % Dirichlet BC at x=1
   
      B = mq(r,shape);      % system matrix 
      dm = H/B;             % discretization D, of linear operator L
            
    U = exactSolution(x,0);  t=0;   % initial condition
    while t < finalTime
         u = rk4(U,t,dt,@F);
         t = t + dt; 
      u(1) = 1; 
      u(N) = exactSolution(1,t);  
         U = u;
    end  % while
    
    exact = exactSolution(x,finalTime);
    subplot(1,2,1), plot(x,exact,'r',x,u,'b')
    subplot(1,2,2), plot(x,abs(U-exact))

   function fp = F(u,t)
       u(1) = 1;   u(N) = exactSolution(1,t); fp =  dm*u;
   end

   function ex = exactSolution(x,t)
          if t<dt
            if length(x)>1
              ex(1)=1; ex(2:length(x))=0; ex = ex(:);
            else, ex = 0; end
          else
             ce = 2.0*sqrt(nu*t); w1 = (x-a*t)/ce;  w2 = (x+a*t)/ce;
             ex = 0.5*(erfc(w1) + exp(a*x/nu).*erfc(w2));
          end
   end
end
