
% INPUTS
%     st  indexes of the fd stencil points
%      x  grid
%      y
%      c  initial shape parameter
%   minK  min condition number of the rbf matrix, e.g. 1e+12
%   maxK  max condition number of the rbf matrix, e.g. 1e+15
%     dc  shape parameter increment, e.g. 0.1
% OUTPUTS
%     wt  weights
%     dm  differentiation matrix

function [dm,wt] = calculateFdStencilWeightsHeatComplex(st,x,y,c,minK,maxK,dc)

       N = length(x);
      wt = zeros(N,length(st(1,:)));        % weights
      dm = zeros(N,N);
    
      for i=1:N
         tn = st(i,find(st(i,:)));
         pn = [tn i];                 % include the base point of the stencil
         
          o = ones(1,length(x(pn)));
         rx = x(pn)*o - (x(pn)*o)';  ry = y(pn)*o - (y(pn)*o)';
          r = sqrt(rx.^2 + ry.^2);
         
         K = 1;
         while (K<minK | K>maxK)      % find a system matrix with desired K
                  B = mq(r,c);     K = cond(B);
                  if K<minK
                    c = c - dc;
                  elseif K>maxK
                    c = c + dc;
                  end   
         end
        
 H = mqDerivatives( sqrt( (x(i)- x(pn)).^2 + (y(i)-y(pn)).^2 ),x(i)- x(pn),c,2) + ...
     mqDerivatives( sqrt( (x(i)- x(pn)).^2 + (y(i)-y(pn)).^2 ),y(i)- y(pn),c,2);
  
         wt(i,1:length(pn)) = H'/B;
         dm(i,pn) = wt(i,1:length(pn));
 
     end % i 
  
  dm = sparse(dm);