 
function [Xn,bpi] = nearOptimalCentersAnnulus(NI,NO,N,M,interiorN) 
% example usage: [Xn,bpi] = nearOptimalCentersAnnulus(30,80,200,200,390); 
% equally space NI centers on interior boundary and NO on the outter
   Xn = zeros(NI + NO + interiorN,2);
   omegaNt = zeros(N*M,2); 
   ti = linspace(0, 2*pi, NI+1)'; ti = ti(1:NI);  r = 1/6;    % inner boundary
   Xn(1:length(ti),1) = r.*cos(ti); 
   Xn(1:length(ti),2) = r.*sin(ti);
   to = linspace(0, 2*pi, NO+1)';  to = to(1:NO);  ro = 0.5;  % outter boundary
   Xn(length(ti)+1:length(to)+length(ti),1) = ro.*cos(to); 
   Xn(length(ti)+1:length(to)+length(ti),2) = ro.*sin(to);
   nbPts = NI + NO;

% --- build a set of center candidates  --------------------------- 
      
      [X,Y] = meshgrid(linspace(-0.5,0.5,N),linspace(-0.5,0.5,M));
      xL = reshape(X,N*M,1);  yL = reshape(Y,N*M,1);
      [th,p] = cart2pol(xL,yL); I = 1;
      for i=1:length(th)
         t = th(i);  r = p(i); ri = 1/6;  ro = 0.5;     
        if (r>ri) & (r<ro)   % add centers between boundaries to omegaN
          if (xL(i)~=0 & yL(i)~=0)
            omegaNt(I,:) = [xL(i) yL(i)];  I = I + 1;
          end
        end
      end
      omegaN = omegaNt(1:I-1,:);  clear omegaNt
      
% ------------ add interiorN centers to Xn -------------------------- 

             N = size(omegaN,1);        % number of candidate centers                          
           bpi = 1:nbPts;               % index of boundary points in the  Xn(i,:)
             n = nbPts;                 % number of centers currently in Xn
    minDstToXn = zeros(N,1); % x in omegaN \ Xn,  distance to its nearest neighbor
 
     for k=1:N
       minDst = 100;
       for j=1:n
         dst = norm(omegaN(k,:)-Xn(j,:),2);
         if dst<minDst & dst>eps, minDst = dst; end % omegaN in Xn already check
         if  dst<eps, minDst = 0; end               % to within machine precision
       end
       minDstToXn(k) = minDst;
     end

     n = n + 1;                                       % add first interior point
     [notUsed,indexAddToXn] = max(minDstToXn); Xn(n,:) = omegaN(indexAddToXn,:);
     minDstToXn(indexAddToXn) = 0;
     
    for k = 1:interiorN       
         for k=1:N                              % update distances for added point
            dst = norm(omegaN(k,:)-Xn(n,:),2);
            if dst<minDstToXn(k) & dst>eps, minDstToXn(k) = dst; end           
            if  dst<eps, minDst = 0; end 
         end
          n = n + 1;                                 % add next interior point
          [notUsed,indexAddToXn] = max(minDstToXn); Xn(n,:) = omegaN(indexAddToXn,:);
          minDstToXn(indexAddToXn) = 0;   
    end 


