%
% poissonTSVD.m
%  
%   MQ asymmetric collocation

   clear, home, close all

  
   Nb = 118;       %  number of boundary points
   Np = 618;       %  total number of center, interior and boundary
     
   centers = dlmread('frankeProblemCenters.txt',' ');   centers = centers;
   x = centers(:,1);  y = centers(:,2);
   
   
       lambda = 0.3;
           mu = 0.8;
      
    u = exp( lambda*x + mu*y );                % exact solution
    f = ( lambda^2 + mu^2  ).*exp( lambda*x + mu*y );


    H = zeros(Np,Np);   rx = zeros(Np,Np);   ry = zeros(Np,Np);   r = zeros(Np,Np);
    
    f(1:Nb) = u(1:Nb);                               % Dirichlet Boundary conditions
 
    for i=1:Np                                                                                 
      for j=1:Np
         rx(i,j) = x(i) - x(j); 
         ry(i,j) = y(i) - y(j); 
         r(i,j) = sqrt( rx(i,j)^2 + ry(i,j)^2 );                    
      end
    end
    
   
  index = 1;
  for shape=16.25:-0.25:0.25;


        H(1:Nb,:) = mq(r(1:Nb,:),shape);                                %   system matrix
        Hxx = mqDerivatives(r(Nb+1:Np,:),rx(Nb+1:Np,:),shape,2);
        Hyy = mqDerivatives(r(Nb+1:Np,:),ry(Nb+1:Np,:),shape,2);
        H(Nb+1:Np,:) = Hxx + Hyy;
        
        kappa(index) = cond(H);
       
         warning off
         alpha = H\f;
         warning on
     
          B = mq(r,shape);                                              %   evaluation matrix
         uh = B*alpha;
  er(index) = norm(u-uh,inf);
  
          
 %       thres = 10e-7;
        
        [alphaSVD,invH,nr,thr] = truncatedSvd(H,f);
        nRank(index) = nr;
        thresHold(index) = thr;

      uha = B*alphaSVD;
         
 erp(index) = norm(u-uha,inf);

         
         
         sh(index) = shape;
             index = index + 1;   

  end

  
   semilogy(sh,er,'b',sh,erp,'r')
   xlabel 'shape parameter', ylabel 'max error'
%{   
   figure
   semilogx(kappa,nRank,'b')
   ylabel 'numerical rank', xlabel '\kappa(H)'
   
   figure
   plot(sh,nRank,'b')
   
   figure
   semilogx(kappa,thresHold,'g')
   xlabel '\kappa(H)', ylabel 'threshold'
 %}
   figure
   loglog(kappa,er,'b',kappa,erp,'r')
   xlabel '\kappa(H)', ylabel 'max error'


%  axis([100 10e5 10e-14 10e-2])
  
